@@ -1,6 +1,6 @@
 // ConfiguratorFactory.cc
 //
-// Copyright (C) 2007, 2008 Rob Caelers
+// Copyright (C) 2007, 2008, 2011 Rob Caelers
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -29,9 +29,8 @@
 #ifdef HAVE_GLIB
 #include "GlibIniConfigurator.hh"
 #endif
-#ifdef HAVE_QT
-#include "QtIniConfigurator.hh"
-#include "QtNativeConfigurator.hh"
+#ifdef HAVE_GSETTINGS
+#include "GSettingsConfigurator.hh"
 #endif
 #ifdef HAVE_GDOME
 #include "XMLConfigurator.hh"
@@ -61,6 +60,14 @@ ConfiguratorFactory::create(Format fmt)
   else
 #endif
 
+#if HAVE_GSETTINGS
+  if (fmt == FormatNative)
+    {
+      b = new GSettingsConfigurator();
+    }
+  else
+#endif
+    
 #ifdef HAVE_GCONF
   if (fmt == FormatNative)
     {
@@ -84,29 +91,15 @@ ConfiguratorFactory::create(Format fmt)
     }
   else
 #endif
-    
-#ifdef HAVE_QT
-  if (fmt == FormatNative)
-    {
-      b = new QtNativeConfigurator();
-    }
-  else
-#endif
 
   if (fmt == FormatIni)
     {
 #ifdef HAVE_GLIB
       b = new GlibIniConfigurator();
-#elif defined(HAVE_QT)
-      b = new QtIniConfigurator();
 #else
 #error Not ported
 #endif
     }
-  else
-    {
-      exit(1);
-    }
 
   if (b != NULL)
     {
